@@ -1,15 +1,15 @@
 #' Probability of Direction (pd)
 #'
-#' Compute the \strong{Probability of Direction} (\strong{\emph{pd}}, also known as the Maximum Probability of Effect - \emph{MPE}). It varies between 50\% and 100\% and can be interpreted as the probability (expressed in percentage) that a parameter (described by its posterior distribution) is strictly positive or negative (whichever is the most probable). It is mathematically defined as the proportion of the posterior distribution that is of the median's sign. Altough differently expressed, this index is fairly similar (i.e., is strongly correlated) to the frequentist \strong{p-value}.
+#' Compute the \strong{Probability of Direction} (\strong{\emph{pd}}, also known as the Maximum Probability of Effect - \emph{MPE}). It varies between 50\% and 100\% (\emph{i.e.}, \code{0.5} and \code{1}) and can be interpreted as the probability (expressed in percentage) that a parameter (described by its posterior distribution) is strictly positive or negative (whichever is the most probable). It is mathematically defined as the proportion of the posterior distribution that is of the median's sign. Altough differently expressed, this index is fairly similar (\emph{i.e.}, is strongly correlated) to the frequentist \strong{p-value}.
 #'
-#' @param x Vector representing a posterior distribution. Can also be a \code{stanreg} or \code{brmsfit} model.
+#' @param x Vector representing a posterior distribution. Can also be a Bayesian model (\code{stanreg}, \code{brmsfit} or \code{BayesFactor}).
 #' @param method Can be \code{"direct"} or one of methods of \link[=estimate_density]{density estimation}, such as \code{"kernel"}, \code{"logspline"} or \code{"KernSmooth"}. If \code{"direct"} (default), the computation is based on the raw ratio of samples superior and inferior to 0. Else, the result is based on the \link[=auc]{Area under the Curve (AUC)} of the estimated \link[=estimate_density]{density} function.
 #' @inheritParams hdi
 #'
 #' @details
 #' \strong{What is the \emph{pd}?}
 #' \cr \cr
-#' The Probability of Direction (pd) is an index of effect existence, ranging from 50\% to 100\%, representing the certainty with which an effect goes in a particular direction (i.e., is positive or negative). Beyond its simplicity of interpretation, understanding and computation, this index also presents other interesting properties:
+#' The Probability of Direction (pd) is an index of effect existence, ranging from 50\% to 100\%, representing the certainty with which an effect goes in a particular direction (\emph{i.e.}, is positive or negative). Beyond its simplicity of interpretation, understanding and computation, this index also presents other interesting properties:
 #' \itemize{
 #'   \item It is independent from the model: It is solely based on the posterior distributions and does not require any additional information from the data or the model.
 #'   \item It is robust to the scale of both the response variable and the predictors.
@@ -84,7 +84,7 @@ pd <- p_direction
 #' @export
 p_direction.numeric <- function(x, method = "direct", ...) {
   if (method == "direct") {
-    pdir <- 100 * max(
+    pdir <- max(
       c(
         length(x[x > 0]) / length(x), # pd positive
         length(x[x < 0]) / length(x) # pd negative
@@ -97,8 +97,8 @@ p_direction.numeric <- function(x, method = "direct", ...) {
     } else {
       dens <- dens[dens$x < 0, ]
     }
-    pdir <- area_under_curve(dens$x, dens$y, method = "spline") * 100
-    if (pdir >= 100) pdir <- 100
+    pdir <- area_under_curve(dens$x, dens$y, method = "spline")
+    if (pdir >= 1) pdir <- 1 # Enforce bounds
   }
 
   attr(pdir, "method") <- method
@@ -141,7 +141,7 @@ p_direction.data.frame <- function(x, method = "direct", ...) {
 #' @export
 p_direction.emmGrid <- function(x, method = "direct", ...) {
   if (!requireNamespace("emmeans")) {
-    stop("Package \"emmeans\" needed for this function to work. Please install it.")
+    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
   }
   xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
   out <- p_direction(xdf, method = method, ...)
