@@ -62,7 +62,7 @@ point_estimate.numeric <- function(x, centrality = "median", dispersion = FALSE,
   if ("all" %in% centrality) {
     estimate_list <- c("median", "mean", "map")
   } else {
-    estimate_list <- c(centrality)
+    estimate_list <- centrality
   }
 
   out <- data.frame(".temp" = 0)
@@ -89,6 +89,10 @@ point_estimate.numeric <- function(x, centrality = "median", dispersion = FALSE,
   }
 
   out <- out[names(out) != ".temp"]
+  attr(out, "data") <- x
+  attr(out, "centrality") <- centrality
+  class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
+
   out
 }
 
@@ -107,6 +111,9 @@ point_estimate.data.frame <- function(x, centrality = "median", dispersion = FAL
 
   out <- cbind(data.frame("Parameter" = names(x), stringsAsFactors = FALSE), estimates)
   rownames(out) <- NULL
+  attr(out, "data") <- x
+  attr(out, "centrality") <- centrality
+  class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
 }
@@ -114,12 +121,15 @@ point_estimate.data.frame <- function(x, centrality = "median", dispersion = FAL
 #' @export
 point_estimate.emmGrid <- function(x, centrality = "median", dispersion = FALSE, ...) {
   if (!requireNamespace("emmeans")) {
-    stop("Package \"emmeans\" needed for this function to work. Please install it.")
+    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
   }
   xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
 
   out <- point_estimate(xdf, centrality = centrality, dispersion = dispersion, ...)
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "centrality") <- centrality
+  class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
+
   out
 }
 
@@ -151,6 +161,9 @@ point_estimate.stanreg <- function(x, centrality = "median", dispersion = FALSE,
     ...
   )
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "centrality") <- centrality
+  class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
+
   out
 }
 
@@ -170,6 +183,9 @@ point_estimate.brmsfit <- function(x, centrality = "median", dispersion = FALSE,
     ...
   )
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "centrality") <- centrality
+  class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
+
   out
 }
 
@@ -179,5 +195,8 @@ point_estimate.brmsfit <- function(x, centrality = "median", dispersion = FALSE,
 point_estimate.BFBayesFactor <- function(x, centrality = "median", dispersion = FALSE, ...) {
   out <- point_estimate(insight::get_parameters(x), centrality = centrality, dispersion = dispersion, ...)
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "centrality") <- centrality
+  class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
+
   out
 }
