@@ -13,14 +13,14 @@ all_summ <- summary(all_)
 test_that("emmGrid ci", {
   testthat::skip_on_travis()
   xci <- ci(all_, ci = 0.9)
-  testthat::expect_equal(xci$CI_low, c(-0.236749774206338, 1.23103419307697, -2.99025704276072), tolerance = 1e-4)
+  testthat::expect_equal(xci$CI_low, c(-0.236749774206338, 1.23103419307697, -2.99025704276072), tolerance = 0.2)
   testthat::expect_equal(xci$CI_high, c(1.83, 3.35, -0.02), tolerance = 0.2)
 })
 
 test_that("emmGrid equivalence_test", {
   testthat::skip_on_travis()
   xeqtest <- equivalence_test(all_, ci = 0.9, range = c(-0.1, 0.1))
-  testthat::expect_equal(xeqtest$ROPE_Percentage, c(5.53, 0, 1.83), tolerance = 0.2)
+  testthat::expect_equal(xeqtest$ROPE_Percentage, c(0.0553, 0, 0.0183), tolerance = 0.2)
   testthat::expect_equal(xeqtest$ROPE_Equivalence, c("Undecided", "Rejected", "Undecided"))
 })
 
@@ -43,7 +43,7 @@ test_that("emmGrid hdi", {
 test_that("emmGrid p_direction", {
   testthat::skip_on_travis()
   xpd <- p_direction(all_, method = "direct")
-  testthat::expect_equal(xpd$pd, c(90.25, 99.9, 95.2), tolerance = 0.1)
+  testthat::expect_equal(xpd$pd, c(0.9025, 0.999, 0.952), tolerance = 0.01)
 })
 
 test_that("emmGrid p_map", {
@@ -55,7 +55,7 @@ test_that("emmGrid p_map", {
 test_that("emmGrid p_rope", {
   testthat::skip_on_travis()
   xprope <- p_rope(all_, range = c(-0.1, 0.1), precision = 0.5)
-  testthat::expect_equal(xprope$p_ROPE, c(69.5, 100, 87), tolerance = 0.1)
+  testthat::expect_equal(xprope$p_ROPE, c(0.695, 1, 0.87), tolerance = 0.1)
 })
 
 test_that("emmGrid point_estimate", {
@@ -69,18 +69,32 @@ test_that("emmGrid point_estimate", {
 test_that("emmGrid rope", {
   testthat::skip_on_travis()
   xrope <- rope(all_, range = "default", ci = .9)
-  testthat::expect_equal(xrope$ROPE_Percentage, c(5.53, 0, 1.83), tolerance = 0.1)
+  testthat::expect_equal(xrope$ROPE_Percentage, c(0.0553, 0, 0.0183), tolerance = 0.1)
 })
 
-test_that("emmGrid bayesfactor_savagedickey", {
+test_that("emmGrid bayesfactor_parameters", {
   testthat::skip_on_travis()
   testthat::skip_on_cran()
   set.seed(4)
-  xsdbf <- bayesfactor_savagedickey(all_, prior = model)
+  xsdbf <- bayesfactor_parameters(all_, prior = model)
   testthat::expect_equal(log(xsdbf$BF), c(-2.5764463544813, 2.00205724074489, -0.235346262395184), tolerance = 1e-4)
   testthat::expect_warning(bayesfactor_savagedickey(all_))
 })
 
+test_that("emmGrid bayesfactor_restricted", {
+  testthat::skip_on_travis()
+  testthat::skip_on_cran()
+  set.seed(4)
+  hyps <- c("`1` < `2`", "`1` < 0")
+  xrbf <- bayesfactor_restricted(em_, prior = model, hypothesis = hyps)
+  testthat::expect_equal(log(xrbf$BF), c(0.64846709184706, -1.64272389006757), tolerance = 1e-4)
+  testthat::expect_equal(xrbf$Prior_prob, c(0.49775, 0.504), tolerance = 1e-2)
+  testthat::expect_equal(xrbf$Posterior_prob, c(0.952, 0.0975), tolerance = 1e-2)
+  testthat::expect_warning(bayesfactor_restricted(em_, hypothesis = hyps))
+})
+
+
+
 test_that("emmGrid describe_posterior", {
   testthat::skip_on_travis()
   testthat::skip_on_cran()
